@@ -1,6 +1,10 @@
 """Routines that pretty-print a hierarchy of logging `Node` objects."""
 
 import logging.handlers
+import sys
+
+if sys.version_info < (2, 6):
+    next = lambda generator: generator.next()  # supply a missing builtin
 
 
 def printout(node=None):
@@ -10,7 +14,7 @@ def printout(node=None):
     active `logging` loggers is printed out.
 
     """
-    print build_description(node),
+    print(build_description(node)[:-1])
 
 
 def build_description(node=None):
@@ -23,20 +27,25 @@ def build_description(node=None):
     if node is None:
         from logging_tree.nodes import tree
         node = tree()
-    return '\n'.join(line.rstrip() for line in describe(node)) + '\n'
+    return '\n'.join([ line.rstrip() for line in describe(node) ]) + '\n'
 
 
 def describe(node):
-    """Generate lines describing the given `node`.
+    """Generate lines describing the given `node` tuple.
 
-    The `node` object should be a `Node` tuple as returned by a routine
-    from the module `logging_tree.nodes`.
+    The `node` should be a tuple returned by `logging_tree.nodes.tree()`.
 
     """
-    logger = node.logger
+    logger = node[1]
     is_placeholder = isinstance(logger, logging.PlaceHolder)
-    arrow = '<--' if (is_placeholder or logger.propagate) else '   '
-    name = ('[%s]' if is_placeholder else '"%s"') % node.name
+    if is_placeholder or logger.propagate:
+        arrow = '<--'
+    else:
+        arrow = '   '
+    if is_placeholder:
+        name = '[%s]' % node[0]
+    else:
+        name = '"%s"' % node[0]
     yield arrow + name
     if not is_placeholder:
         if logger.level:
@@ -52,17 +61,21 @@ def describe(node):
             yield '   Filter %s' % describe_filter(f)
         for h in getattr(logger, 'handlers', ()):
             g = describe_handler(h)
-            yield '   Handler %s' % g.next()
+            yield '   Handler %s' % next(g)
             for line in g:
                 yield '   ' + line
 
-    if node.children:
-        last_child = node.children[-1]
-        for child in node.children:
+    children = node[2]
+    if children:
+        last_child = children[-1]
+        for child in children:
             g = describe(child)
             yield '   |'
-            yield '   o' + g.next()
-            prefix = '    ' if (child is last_child) else '   |'
+            yield '   o' + next(g)
+            if child is last_child:
+                prefix = '    '
+            else:
+                prefix = '   |'
             for line in g:
                 yield prefix + line
 
@@ -74,7 +87,7 @@ def describe(node):
 
 def describe_filter(f):
     """Return text describing the logging filter `f`."""
-    if type(f) is logging.Filter:
+    if f.__class__ is logging.Filter:  # using type() breaks in Python <= 2.6
         return 'name=%r' % f.name
     return repr(f)
 
@@ -84,10 +97,6 @@ handler_formats = {  # Someday we will switch to .format() when Py2.6 is gone.
     logging.FileHandler: 'File %(baseFilename)r',
     logging.handlers.RotatingFileHandler: 'RotatingFile %(baseFilename)r'
         ' maxBytes=%(maxBytes)r backupCount=%(backupCount)r',
-    logging.handlers.TimedRotatingFileHandler:
-        'TimedRotatingFile %(baseFilename)r when=%(when)r'
-        ' interval=%(interval)r backupCount=%(backupCount)r',
-    logging.handlers.WatchedFileHandler: 'WatchedFile %(baseFilename)r',
     logging.handlers.SocketHandler: 'Socket %(host)s %(port)r',
     logging.handlers.DatagramHandler: 'Datagram %(host)s %(port)r',
     logging.handlers.SysLogHandler: 'SysLog %(address)r facility=%(facility)r',
@@ -97,10 +106,20 @@ handler_formats = {  # Someday we will switch to .format() when Py2.6 is gone.
     logging.handlers.MemoryHandler: 'Memory capacity=%(capacity)r dumping to:',
     }
 
+if sys.version_info >= (2, 5): handler_formats.update({
+    logging.handlers.TimedRotatingFileHandler:
+        'TimedRotatingFile %(baseFilename)r when=%(when)r'
+        ' interval=%(interval)r backupCount=%(backupCount)r',
+    })
+
+if sys.version_info >= (2, 6): handler_formats.update({
+    logging.handlers.WatchedFileHandler: 'WatchedFile %(baseFilename)r',
+    })
+
 
 def describe_handler(h):
     """Yield one or more lines describing the logging handler `h`."""
-    t = type(h)
+    t = h.__class__  # using type() breaks in Python <= 2.6
     format = handler_formats.get(t)
     if format is not None:
         yield format % h.__dict__
@@ -108,7 +127,7 @@ def describe_handler(h):
             yield '  Filter %s' % describe_filter(f)
         if t is logging.handlers.MemoryHandler and h.target is not None:
             g = describe_handler(h.target)
-            yield '  Handler ' + g.next()
+            yield '  Handler ' + next(g)
             for line in g:
                 yield '  ' + line
     else:
